@@ -6,7 +6,7 @@ use FlashVideo::Utils;
 use HTML::Entities;
 use Encode;
 
-our $VERSION = '0.03';
+our $VERSION = '0.07';
 sub Version() { $VERSION;}
 
 sub find_video {
@@ -53,6 +53,9 @@ EOF
   }
   else {
     ($productionid) = $browser->content =~ /\"productionId\":\"([^\"]+)\"/i;
+    if (! $productionid) {
+      ($productionid) = $browser->content =~ / data-video-id\s*=\s*\"([^\"]+)\"/i;
+    }
     debug "Production ID $productionid\n";
     die "No id (filter) found in URL or production id\n" unless $productionid;
     $browser->post("http://mercury.itv.com/PlaylistService.svc",
@@ -112,10 +115,26 @@ EOF
 
   my %formats;
 
+  my $progtitle;
+  my $eptitle;
+  if ($browser->content =~ m%<ProgrammeTitle>(.*?)</ProgrammeTitle>% ) {
+    $progtitle = $1;
+    $progtitle =~ s/\W+/-/g;
+  }
+  if ( $browser->content =~ m%<EpisodeTitle>(.*?)</EpisodeTitle%) {
+    $eptitle = $1;
+    $eptitle =~ s/\W+/-/g;
+  }
+
 # Normal format for catchup service
-  while ($video =~ m/(mp4:[^\]]+_[A-Z]+([0-9]{3,4})_(16|4)[-x](9|3)[^\]]*.mp4)/gi)
+  while ($video =~ m/(mp4:[^\]]+_[A-Z]+([0-9]{3,4})(|_[^\]]+)_(16|4)[-x](9|3)[^\]]*.mp4)/gi)
   {
-    $formats{$2} = { video => $video, playpath => $1, ratio => "$3x$4" };
+    $formats{$2} = { video => $video, playpath => $1, ratio => "$4x$5" };
+  }
+
+  while ($video =~ m/(mp4:[^\]]+_PC01([0-9]{3,4})(|_[^\]]+)_(16|4)[-x](9|3)[^\]]*.mp4)/gi)
+  {
+    $formats{$2} = { video => $video, playpath => $1, ratio => "$4x$5" };
   }
 
 # alternative formats when download available immediately after shows
@@ -160,6 +179,10 @@ EOF
   my($playpath) = $format->{"playpath"};
   my($flv) = $playpath =~ m{/([^/]+)$};
   $flv =~ s/\.mp4$/.flv/;
+  if ( $flv =~ /_PC01\d+_/i ) {
+    $flv =~ s/_/_${progtitle}-${eptitle}_/;
+    $flv = title_to_filename($flv);
+  } 
 
   # Get subtitles if necessary.
   if ($prefs->{subtitles}) {
